@@ -66,7 +66,7 @@ KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
     setNeedsAuthorization(true);
 
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     _wcw = new WalletConfigWidget(this);
     vbox->addWidget(_wcw);
 
@@ -381,7 +381,7 @@ void KWalletConfig::customContextMenuRequested(const QPoint &pos)
     if (item && item->parent()) {
         QMenu *m = new QMenu(this);
         m->setTitle(item->parent()->text(0));
-        m->addAction(i18n("&Delete"), this, SLOT(deleteEntry()), Qt::Key_Delete);
+        m->addAction(i18n("&Delete"), this, &KWalletConfig::deleteEntry, Qt::Key_Delete);
         m->exec(_wcw->_accessList->mapToGlobal(pos));
         delete m;
     }
